/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/

/*! \file MainWidget.h
    \brief Implements widget for maemo that allows user to search quickly right from home screen using mdictionary.

    \author Mateusz Półrola <mateusz.polrola@comarch.pl>
*/

#ifndef MAINWIDGET_H
#define MAINWIDGET_H

#include <QWidget>
#include <QtGui>
#include <QtDBus/QDBusConnection>
#include <QPushButton>

/*!
  Shows tool button with logo of mDictionary which can start application.
  In line edit user inputs word, and after using button next to it or pressing enter, widget runs mDictionary which immediately starts searching for a given word.
  If mDictionary is already running in background it will show the program.
  */
class HomeWidget : public QWidget
{
    Q_OBJECT
public:
    HomeWidget(QWidget *parent = 0);

private slots:
    void search();
    void logoClicked();

protected:
    /*! Reimplemented paintEvent to display rounded corners with transparency */
    void paintEvent(QPaintEvent *);

private:
    /*! Initializes ui of widget*/
    void initializeUI();

    /*! Initializes X11 to set application type as home widget*/
    void initializeX11();


    QLineEdit* searchStringLineEdit;
    QPushButton* searchButton;
    QToolButton* logo;
    QHBoxLayout* horizontalLayout;
};

#endif // MAINWIDGET_H
