/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/

/*!
    \file BookmarkTranslation.h
    \brief Bookmarks functionality needs its own translation object - because
    Translation object should use slightly different api of Bookmarks objects

    \author Bartosz Szatkowski <bulislaw@linux.com>
*/
#ifndef BOOKMARKTRANSLATIONS_H
#define BOOKMARKTRANSLATIONS_H

#include "../../include/settings.h"
#include "../../include/translation.h"
#include "Bookmarks.h"
#include "QObject"



class BookmarkTranslation : public Translation
{
public:
    BookmarkTranslation(QString key, Bookmarks* bookmarks, QString dbName){
        _key = key;
        _dictionaryInfo = dbName;
        _bookmarks = bookmarks;
        _bookmark = 2;
    }

    //! \return word to be translated
    QString key() const {
        return _key;
    }

    //! \return parsed raw format into xml
    QString toXml() const {
        if(!_key.size() || !_bookmarks)
            return "";

        QStringList list = _bookmarks->search(_key, _dictionaryInfo);
        QString result;
        foreach(QString translation, list)
            result += translation + "\n";
        return result;

    }

    /*!
        sets the word for which we want to find a translation
        \param word for which we want to find a translation
    */
    void setKey(QString key) {
        _key = key;
    }

    //! sets information about dictionary
    void setDictionaryInfo(QString dictionaryInfo) {
        _dictionaryInfo = dictionaryInfo;
    }


private:
    QString _key;
    QString _dictionaryInfo;
    Bookmarks* _bookmarks;

};

#endif // HISTORYTRANSLATION_H
