/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/
/*! \file AboutWidget.cpp
    \brief Simple "about" widget - product, company, license info

    \author Bartosz Szatkowski <bulislaw@linux.com>
*/

#include "AboutWidget.h"


AboutWidget::AboutWidget(GUIInterface *parent): QDialog(parent)
{
    setWindowTitle(tr("About"));

#ifndef Q_WS_MAEMO_5
    resize(380,450);

    view= new QDeclarativeView();
    view->setSource(QUrl::fromLocalFile("/usr/share/mdictionary/qml/AboutWidget.qml"));
    view->setResizeMode(QDeclarativeView::SizeRootObjectToView);
    view->setAlignment(Qt::AlignCenter);
    view->show();

    mainLayout = new QVBoxLayout;
    mainLayout->addWidget(view);

    QGraphicsObject *rootObject = view->rootObject();
    connect(rootObject, SIGNAL(linkClicked(QString)), this, SLOT(openUrl(QString)));
    this->setLayout(mainLayout);

#else
    setModal(true);
    QString infoNote, licenseNote, comarchNote;
    infoNote = "<center><h2><u>mDictionary</u></h2></center>";
    comarchNote = "<center>Maemo/Meego Multilingual Dictionary</center>";
    comarchNote += "<center>Copyright 2006-2010, Comarch S.A. <br>";
    comarchNote += "<a href=\"http://mdictionary.garage.maemo.org\">"
                   "http://mdictionary.garage.maemo.org</a>";
    comarchNote += "<br/><font size=\"small\"><a href=\"https://garage.maemo.org/tracker/?func=add&group_id=58&atid=305\">"
                   "Report bug</a></font></center>";
    licenseNote = QString("<br><p><font size=\"small\">This program is free"
                  " software: you can redistribute it and/or modify\n"
                  "it under the terms of the GNU General Public License as"
                  " published by\n"
                  "the Free Software Foundation, either version 3 of the License,"
                  " or\n"
                  "(at your option) any later version.<br>"
                  "This program is distributed in the hope that it will be"
                  " useful,\n"
                  "but WITHOUT ANY WARRANTY; without even the implied warranty"
                  " of\n"
                  "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. "
                  "See the\n"
                  "GNU General Public License for more details.<br>"
                  "You should have received a copy of the GNU General Public "
                  "License<br>"
                  "along with this program.  If not, see"
                  "&lt;<a href=\"http://www.gnu.org/licenses/\">"
                  "http://www.gnu.org/licenses/</a>&gt;."
                  "</p></font>");
    mainLayout = new QVBoxLayout;

    imageLabel = new QLabel;
    mainLabel = new QLabel;
    licenseLabel = new QLabel;


    QImage img(":/icons/logo/mdictionary.png");
    imageLabel->setPixmap(QPixmap::fromImage(img));
    imageLabel->setMinimumSize(imageLabel->pixmap()->size());

    mainLabel->setText(infoNote + comarchNote);
    mainLabel->setOpenExternalLinks(true);
    mainLabel->setMinimumSize(mainLabel->sizeHint());


    licenseLabel->setWordWrap(true);
    licenseLabel->setText(licenseNote);
    licenseLabel->setOpenExternalLinks(true);
    licenseLabel->setMinimumSize(licenseLabel->sizeHint());


    mainLayout->addWidget(imageLabel, 0, Qt::AlignHCenter);
    mainLayout->addWidget(mainLabel, 0, Qt::AlignHCenter);
    mainLayout->addWidget(licenseLabel, 0, Qt::AlignHCenter);

    setLayout(mainLayout);
#endif
}


void AboutWidget::openUrl(QString url){
    QDesktopServices::openUrl(url);
}
