/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/

/*! \file NotifyManager.h
    \brief Manages notifications in applications

    \author Mateusz Półrola <mateusz.polrola@comarch.pl>
*/

#ifndef NOTIFYMANAGER_H
#define NOTIFYMANAGER_H

#include <QObject>
#include <QHash>
#include <QString>
#include <QDialog>
#include "../../include/Notify.h"
#include "MenuWidget.h"

/*!
    Shows notifications to user, assures that a couple of the same notifications
    will not be displayed at the same time. It automatically deletes
    notifications after user accepts or rejects them.
*/

class NotifyManager : public QObject
{
    Q_OBJECT
public:
    NotifyManager(QObject *parent = 0);

public slots:
    //! Shows notification
    /*!
        Displays new notification of passed type containing passed text
        \param type type of notification
        \param text text of notification
        \sa Notify::NotifyType
    */
    void showNotification(Notify::NotifyType type, QString text);

    //! Refresh all notifications when stacked widgets changes
    void screenChanged();

    void setMenu(QWidget*);

private slots:
    //! Informs that notification was closed and can be deleted
    void notificationClosed();

private:
    QHash<QString, QDialog*> activeNotifies;
    QWidget* menu;
};

#endif // NOTIFYMANAGER_H
