/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/
/*! \file TranslationWidget.h
    \brief Displays translation of a word found in dictionaries

    \author Mateusz Półrola <mateusz.polrola@comarch.pl>
*/

#ifndef TRANSLATIONWIDGET_H
#define TRANSLATIONWIDGET_H

#include <QWidget>
#include <QModelIndex>
#include <QtGui>
#include "../backbone/backbone.h"
#include <QtXml>
#include <QXmlQuery>
#include "TranslationView.h"
#include <QPropertyAnimation>
#include "../../include/GUIInterface.h"

/*!
    Displays many translations of word, formatted as xml.
*/
class TranslationWidget : public QScrollArea {
    Q_OBJECT
public:
    explicit TranslationWidget(QWidget *parent = 0);

Q_SIGNALS:
    void search(QString);
    void notify(Notify::NotifyType, QString);

public Q_SLOTS:
    //! Show widget.
    void show();

    //! Requests to show a translation of words list passed as parameter.
    void show(QStringList);

    //! Updates user's zoom preferences and sends its to backbone to be saved
    void updateZoom(qreal);

protected:
    #ifdef Q_WS_MAEMO_5
        void keyPressEvent(QKeyEvent *);
        void hideEvent(QHideEvent *);
    #endif

private Q_SLOTS:
    void searchSelected();
    void copySelected();
    #ifdef Q_WS_MAEMO_5
        void showButtons();
    #endif

private:
    QString XslConversion(QString translation);
    QString checkTranslation(QString trans);
    QString createTranslation(QStringList translations);
    QToolButton* zoomInToolButton;
    QToolButton* zoomOutToolButton;
    TranslationView *webkit;
    QString xslt;

    #ifdef Q_WS_MAEMO_5
        QToolButton* zoomInButton;
        QToolButton* zoomOutButton;
        QToolButton* selectAllButton;
        QToolButton* copyButton;
        QToolButton* searchButton;
        QToolButton* showButtonsButton;

        QPropertyAnimation* zoomInButtonAnimation;
        QPropertyAnimation* zoomOutButtonAnimation;
        QPropertyAnimation* copyButtonAnimation;
        QPropertyAnimation* selectAllButtonAnimation;
        QPropertyAnimation* searchButtonAnimation;
        QAnimationGroup* buttonsAnimation;

        void initButtons();
        bool buttonsInitialized;
        bool buttonsVisible;

        void grabZoomKeys(bool);
    #endif

    QVBoxLayout *verticalLayout;
    QHBoxLayout* horizontalLayout;
    GUIInterface* guiinterface;

    void initializeUI();
};

#endif // TRANSLATIONWIDGET_H
