#ifndef WORDLISTMODEL_H
#define WORDLISTMODEL_H

#include <QAbstractListModel>
//#include "../../include/GUIInterface.h"
#include "../../include/translation.h"

class WordListModel : public QAbstractListModel
{
    Q_OBJECT
public:

    enum DictTypeRoles
    {
        WordRole = Qt::UserRole + 1,
        IsBookmarkedRole,
        NumberRole
    };

    explicit WordListModel(QObject *parent = 0);

    int rowCount(const QModelIndex & parent = QModelIndex()) const;

    QVariant data(const QModelIndex & index, int role = Qt::DisplayRole) const;
    bool setData(const QModelIndex &index, const QVariant &value, int role);

    Qt::ItemFlags flags(const QModelIndex &index) const;

    //! Replace model data and refresh ui.
    /*!
      \param dictionaries hash set (dictionary, is active) with dictionaries
    */
    void setTranslations(QHash<QString, QList<Translation*> > translations, QHash<QString, bool> wordsInBookmarks);
    //! Clear model data and refresh UI
    void clear();

    void sort(int column, Qt::SortOrder order = Qt::AscendingOrder);

signals:

    void addToBookmarks(QString word);

    void removeFromBookmarks(QString word);

public slots:

    //! Set value at role in index row of data.
    /*!
      \param index word position in data list
      \param value new value for role
      \param role role name
      */
    void setModelProperty(int index, const QVariant value, QString role);

private:
    int setDataPriv(int index, const QVariant &value, int role);
    void addWord(QString word, QList<Translation*> translations, bool isBookmarked);

    QHash<QString, QList<Translation*> > _translations;
    QHash<QString, bool > _wordInBookmarks;
    QList<QString> _wordList;

    void ascendingQuickSort(int left, int right);
    void descendingQuickSort(int left, int right);

};

#endif // WORDLISTMODEL_H
