/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/
/*!
    \file CompressedReader.cpp
    \brief Class implementing StarDictReader interface and handling reading from compressed
    files like .gz or .dz

    \author Mateusz Półrola
*/

#include "CompressedReader.h"
#include <QtEndian>
#include <QDebug>

CompressedReader::CompressedReader(QObject *parent) :
    StarDictReader(parent) {
}


CompressedReader::CompressedReader(QString filename, QObject *parent) :
    StarDictReader(parent) {
    open(filename);
}


CompressedReader::~CompressedReader() {
    if(_file != NULL)
        gzclose(_file);
}


bool CompressedReader::open(QString file) {
    _file = gzopen(file.toStdString().c_str(), "rb");
    if(_file == NULL)
        return false;
    return true;
}


void CompressedReader::close() {
    gzclose(_file);
    _file = NULL;
}


QChar CompressedReader::readChar() {
    char c[4]={0};
    QString cha;

    gzread(_file, c, 1);
    if(((unsigned char)c[0])>239)
        gzread(_file, c+1, 3);
    else if(((unsigned char)c[0])>223)
        gzread(_file, c+1, 2);
    else if(((unsigned char)c[0])>191)
        gzread(_file, c+1, 1);
    else if(((unsigned char)c[0])>127){
        qDebug()<<"error - starDict - read wordList from UTF-8";
        c[0]=0;
    }

    cha=QString::fromUtf8(c);
    if(cha.size()!=0)
        return cha.at(0);
    else
        return '\0';
}


qint32 CompressedReader::readInt32BigEndian() {
    qint32 value;
    gzread(_file, (void*)(&value), 4);
    return qFromBigEndian(value);
}


qint64 CompressedReader::readInt64BigEndian() {
    qint64 value;
    gzread(_file, (void*)(&value), 8);
    return value;
}


QString CompressedReader::readKeyword() {
    QString result;
    QChar c;

    c = readChar();
    while(c != '\0') {
        result += c;
        c = readChar();
    }
    return result;
}


QByteArray CompressedReader::readString(qint64 offset, qint32 len) {
    char* buf;
    buf = new char[len];

    gzseek(_file, offset, SEEK_SET);
    gzread(_file, buf, len);

    QByteArray res(buf, len);
    delete [] buf;
    return res;
}

