/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/
/*!
    \file XdxfDictDownloadProgressDialog.cpp
    \brief Shows downloading progress bar.

    \author Mateusz Półrola <mateusz.polrola@comarch.com>
*/

#include "XdxfDictDownloadProgressDialog.h"

XdxfDictDownloadProgressDialog::XdxfDictDownloadProgressDialog(QWidget*parent):
    QDialog(parent) {
    verticalLayout = new QVBoxLayout(this);
    setLayout(verticalLayout);

    downloadProgressBar = new QProgressBar(this);
    downloadProgressBar->setMinimum(0);
    downloadProgressBar->setMaximum(0);
    downloadProgressBar->setTextVisible(true);

    cancelButton = new QPushButton(tr("Cancel"),this);

    connect(cancelButton, SIGNAL(clicked()),
            this, SIGNAL(cancelDownloading()));

    #ifndef Q_WS_MAEMO_5
            downloadLabel = new QLabel(this);
            verticalLayout->addWidget(downloadLabel, 0, Qt::AlignCenter);
    #endif

    verticalLayout->addWidget(downloadProgressBar);
    verticalLayout->addWidget(cancelButton);
    setModal(true);

    #ifndef Q_WS_MAEMO_5
        setMinimumWidth(350);
    #endif
}


void XdxfDictDownloadProgressDialog::show() {
    downloadProgressBar->setMaximum(0);
    QDialog::show();
}


void XdxfDictDownloadProgressDialog::setText(QString text) {
    setWindowTitle(text);
    #ifndef Q_WS_MAEMO_5
        downloadLabel->setText(text);
    #endif
}


void XdxfDictDownloadProgressDialog::updateProgress(float progress) {
    if(downloadProgressBar->maximum() == 0) {
        downloadProgressBar->setMaximum(100);
    }
    downloadProgressBar->setValue(progress*100);
}


void XdxfDictDownloadProgressDialog::reject() {
    #ifndef Q_WS_MAEMO_5
        Q_EMIT cancelDownloading();
    #else
        return;
    #endif
}
